@@ -241,7 +241,7 @@ def _write_dist_release_files(origin, dist_name, dist_root, component_names,
     gpg = 'gpg -u %s' % key_id if key_id else 'gpg'
 
     subprocess.check_call(
-        '%s --sign < Release > Release.gpg' % gpg,
+        '%s --detach-sign < Release > Release.gpg' % gpg,
         shell=True,
         cwd=dist_root,
     )
